#  RealEstateBroker http://sf.net/projects/collective/
#  Archetypes Content Type for publishing houses
#  Copyright (c) 2003-2004 Zopeworks
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#  Authors: A.Hadi - zopeworks <ahadi@zopeworks.nl>
#           J.P.Ladage - zopeworks <jladage@zopeworks.nl>

from Products.Archetypes.public import listTypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.RealEstateBroker import config
from Products.RealEstateBroker.config import *
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFDefault.PropertiesTool import PropertiesTool
from StringIO import StringIO
from Products.CMFCore.CMFCorePermissions import ManagePortal, \
     SetOwnProperties

broker_configlet = {'id': 'RealEstateBroker',
                    'appId': 'RealEstateBroker',
                    'name': 'Real Estate Broker settings',
                    'action': 'string:$portal_url/prefs_broker_form',
                    'category': 'Products',
                    'permission': ManagePortal,
                    'imageUrl': 'h_icon.gif'
                   }
    

def install(self):
    out = StringIO()
    installTypes(self, out,
                 listTypes(PROJECTNAME),
                 PROJECTNAME)

    install_subskin(self, out, GLOBALS)


    if not hasattr(self.portal_properties, 'realestate_properties'):
        self.portal_properties.addPropertySheet('realestate_properties', 'Real Estate Properties')
        props = self.portal_properties.realestate_properties
        props._setProperty('city', ['Amsterdam', 
                                    'New York', 
                                    'London', 
                                    'Alberschwende'], 'lines')
        props._setProperty('rooms', ['1', '2', '3', '4', '5', '6', '7', '8'], 'lines')
        props._setProperty('min_price', ['0', '100000', '150000', '200000', 
                                         '250000', '300000', '350000', '400000', '450000', 
                                         '500000', '600000', '700000', '800000', '900000', 
                                         '1000000', '1250000', '1500000', '2000000'], 'lines')
        props._setProperty('max_price', ['0', '100000', '150000', '200000', 
                                         '250000', '300000', '350000', '400000', '450000', 
                                         '500000', '600000', '700000', '800000', '900000', 
                                         '1000000', '1250000', '1500000', '2000000'], 'lines')
        props._setProperty('type', ['Appartment', 
                                    'Villa', 
                                    'Mansion'], 'lines') 
        props._setProperty('kindOfBuilding', ['New', 'Existing'], 'lines') 
        props._setProperty('balcony', ['Yes', 'No'], 'lines')
        props._setProperty('garden', ['Yes', 'No'], 'lines')
        props._setProperty('kindOfGarden', ['Backyard', 'Frontyard'], 'lines')
        props._setProperty('garage', ['Yes', 'No'], 'lines')
        props._setProperty('kindOfGarage', ['drive-in', 'Shed'], 'lines')
        props._setProperty('location', ['Forest', 'Shore'], 'lines')
        props._setProperty('storage', ['Yes', 'No'], 'lines')
        props._setProperty('heating', ['Fireplace', 'City Heating'], 'lines')
        props._setProperty('isolation', ['Floor', 'Dubble glas'], 'lines')
        props._setProperty('airco', ['Yes', 'No'], 'lines')
        props._setProperty('status', ['new', 'available', 'negotiating', 'sold'], 'lines')
        props._setProperty('currency', '&euro;', 'string')

	        
    
    tab = getToolByName(self, 'portal_actions')
    tab_actions=tab._cloneActions()
    actionDefined=0
    for a in tab_actions:
        if a.id=='REBroker_view':
            a.visible=1
            actionDefined=1
        tab._actions=tab_actions
            
    if actionDefined == 0:                    
        tab.addAction('REBroker_view',
                      'RealEstateBroker',
                      'string:$portal_url/REBroker_view',
                      '',
                      'View',
                      'portal_tabs')
               
    print >> out, "Successfully added realestate_properties to portal_properties."
    

    self.portal_controlpanel.registerConfiglet(**broker_configlet)
       
    # install validation
    form_tool = getToolByName(self, 'portal_form')
    for form, val in validators.items():
        form_tool.setValidators(form, val)

    nav_tool = getToolByName(self, 'portal_navigation')
    
    # install navigation
    for tp, a1 in forms.items():
        for form, a2 in a1.items():
            for st, trans in a2.items():
                nav_tool.addTransitionFor(tp, form, st, trans)
                
    
    print >> out, "Successfully added Real Estate Broker Settings to portal_controlpanel and plone memberprefs control." 
    
    navtree_props = getToolByName(self, 'portal_properties').navtree_properties
    nav_tree_notlisted = navtree_props.getProperty('metaTypesNotToList', None)
    if not 'REHome' in nav_tree_notlisted:
        navtree_props._updateProperty('metaTypesNotToList', tuple(nav_tree_notlisted) +
                                     ('REHome',))

    print >> out, "Added REHome to portal_properties/navtree_properties/metaTypesNotToList"
    
    mdtool = self.portal_memberdata
    addprop = mdtool.manage_addProperty
    addprop('newsletter', 0, 'boolean')
    addprop('city', '', 'lines')
    addprop('min_price', '', 'string')
    addprop('max_price', '', 'string')
    
    print >> out, "Added memberdata properties to portal_memberdata tool"

    catalog = self.portal_catalog
    catalog.manage_addColumn('address')
    catalog.manage_addColumn('price')
    catalog.manage_addColumn('city')
    catalog.manage_addColumn('status')
    
    print >> out, "Successfully installed %s." % PROJECTNAME

    return out.getvalue()

def uninstall(self):
    out = StringIO()
    # uninstall configs
    
    self.portal_controlpanel.unregisterConfiglet(broker_configlet['id'])
    #self.portal_controlpanel.unregisterConfiglet(news_configlet['id'])
    
    nav_tool = getToolByName(self, 'portal_navigation')       
    nav_tool.removeTransitionFrom('default', 'prefs_broker_form', 'success')
    nav_tool.removeTransitionFrom('default', 'prefs_broker_form', 'failure')       
    nav_tool.removeTransitionFrom('default', 'prefs_broker_set', 'success')
    
    property_tool = getattr(self, 'portal_properties')
    formprops = getattr(property_tool, 'form_properties')
    formprops._delProperty('prefs_broker_form')
    
    props = getToolByName(self, 'portal_properties')
    props._delObject('realestate_properties')
    
    mdtool = getToolByName(self, 'portal_memberdata')
    mdtool._delProperty('newsletter')
    mdtool._delProperty('city')
    mdtool._delProperty('min_price')
    mdtool._delProperty('max_price')
    
    catalog = self.portal_catalog
    catalog.manage_delColumn('address')
    catalog.manage_delColumn('price')
    catalog.manage_delColumn('city')
    catalog.manage_delColumn('status')

    tab = getToolByName(self, 'portal_actions')
    tab_actions=tab._cloneActions()
    for a in tab_actions:
        if a.id=='REBroker_view':
            a.visible=0
        tab._actions=tab_actions 
        
                     
    return out.getvalue()
