#  RealEstateBroker http://sf.net/projects/collective/
#  Archetypes Content Type for publishing houses
#  Copyright (c) 2003-2004 Zopeworks
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#  Authors: A.Hadi - zopeworks <ahadi@zopeworks.nl>
#           J.P.Ladage - zopeworks <jladage@zopeworks.nl>
#
from Products.Archetypes.public import *
from Products.CMFCore import CMFCorePermissions
from Products.RealEstateBroker.config import AVAILABLE_STATES
import string

schema = BaseFolderSchema + Schema((
               
    TextField('address',
               index='FieldIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the address of this object",
                                   description_msgid = "desc_address",
                                   label = "Address",
                                   label_msgid = "label_address",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='General info' ),

    TextField('zipCode',
               index='TextIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the zip code of this object",
                                   description_msgid = "desc_zipCode",
                                   label = "Zip code",
                                   label_msgid = "label_zipCode",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='General info' ),
               
    TextField('city',
               index='TextIndex',
               required = 1,
               vocabulary='_get_city_vocab',
               widget=SelectionWidget(description = "Fill in the city",
                                      description_msgid = "desc_city",
                                      label = "City",
                                      label_msgid = "label_city",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),
               
    IntegerField('price',
               index='FieldIndex',
               required = 1,
               widget=IntegerWidget(description = "Fill in the Price without dots or comma's",
                                    description_msgid = "desc_price",
                                    label = "Price",
                                    label_msgid = "label_price",
                                    i18n_domain = "broker",
                                    size = 30),
               schemata='General info' ),
                                  
               
    TextField('type',
               index='FieldIndex',
               vocabulary='_get_type_vocab',
               required = 1,
               widget=SelectionWidget(description = "Select the type object",
                                      description_msgid = "desc_type",
                                      label = "Type",
                                      label_msgid = "label_type",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),
               
    TextField('rooms',
                required = 1,
                index='FieldIndex',
                vocabulary='_get_rooms_vocab',
                widget=SelectionWidget(label="Rooms",
                                       label_msgid = "label_rooms",
                                       description="Select the available rooms",
                                       description_msgid = "desc_rooms",
                                       i18n_domain = "broker",),
               schemata='General info' ),

    TextField('status',
                required = 1,
                index='FieldIndex',
                vocabulary=AVAILABLE_STATES,
                widget=SelectionWidget(label="Status",
                                       label_msgid = "label_status",
                                       description="Select the status",
                                       description_msgid = "desc_status",
                                       i18n_domain = "broker",),
                schemata='General info' ),
                
    TextField('desc',
               required = 1,
               widget=TextAreaWidget(description = "Enter a short description for this object",
                                     description_msgid = "desc_desc",
                                     label = "Description",
                                     label_msgid = "label_desc",
                                     i18n_domain = "broker",
                                     rows = 3),
               schemata='Description' ),
    
    TextField('mainText',
               required = 1,
               default_content_type = 'text/restructured',
               default_output_type = 'text/html',
               allowable_content_types = ('text/html',),
               widget = RichWidget(description = "Enter the main description for this object",
                                   description_msgid = "desc_mainText",
                                   label = "Body text",
                                   label_msgid = "label_mainText",
                                   i18n_domain = "broker",
                                   rows = 25 ),
               schemata='Description' ), 
               
    TextField('area',
               index='FieldIndex',
               required = 0,
               widget=StringWidget(description = "Fill in the area",
                                   description_msgid = "desc_area",
                                   label = "Area",
                                   label_msgid = "label_area",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),
               
    TextField('constructYear',
               required = 0,
               widget=StringWidget(description = "Fill in the construct year or the period of this object",
                                   description_msgid = "desc_constructYear",
                                   label = "Construct year",
                                   label_msgid = "label_constructYear",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),
                            
    LinesField('location',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_location_vocab',
                widget=MultiSelectionWidget(label="Location",
                                            label_msgid = "label_location",
                                            description="""Select the location. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while 
                                                           left clicking the options""",
                                            description_msgid = "desc_location",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),
                                                        
    TextField('kindOfBuilding',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfBuilding_vocab',
                widget=SelectionWidget(label="Kind of building",
                                       label_msgid = "label_kindOfBuilding",
                                       description="Select what kind of building this is",
                                       description_msgid = "desc_kindOfBuilding",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    TextField('volume',
               required = 0,
               widget=StringWidget(description = "Fill in the volume of this object",
                                   description_msgid = "desc_volume",
                                   label = "Volume",
                                   label_msgid = "label_volume",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),
               
    TextField('balcony',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_balcony_vocab',
                widget=SelectionWidget(label="Balcony",
                                       label_msgid = "label_balcony",
                                       description="Select whether this object has a balcony",
                                       description_msgid = "desc_balcony",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    TextField('garden',
               required =  0,
               index='FieldIndex',
               vocabulary='_get_garden_vocab',
               widget=SelectionWidget(label="Garden",
                                      label_msgid = "label_garden",
                                      description="Select whether this object has a garden",
                                      description_msgid = "desc_garden",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),
                                          
    LinesField('kindOfGarden',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfGarden_vocab',
                widget=MultiSelectionWidget(label="Kind of garden",
                                       label_msgid = "label_kindOfGarden",
                                       description="""Select the kind of garden. You can choose more than 1 option. 
                                                      Multiple options can be selected/deselected by pressing Ctrl while 
                                                      left clicking the options""",
                                       description_msgid = "desc_kindOfGarden",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    TextField('gardenWidth',
               required = 0,
               widget=StringWidget(description = "Fill in the garden width (in m)",
                                   description_msgid = "desc_gardenWidth",
                                   label = "Garden width",
                                   label_msgid = "label_gardenWidth",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),
               
    TextField('gardenDepth',
               required = 0,
               widget=StringWidget(description = "Fill in the garden depth (in m)",
                                   description_msgid = "desc_gardenDepth",
                                   label = "Garden depth",
                                   label_msgid = "label_gardenDepth",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),
               
    TextField('storage',
               required = 0,
               index='FieldIndex',
               vocabulary='_get_storage_vocab',
               widget=SelectionWidget(label="Storage",
                                      label_msgid = "label_storage",
                                      description="Select whether this object has a storage",
                                      description_msgid = "desc_storage",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),
                
    TextField('garage',
               required = 0,
               index='FieldIndex',
               vocabulary='_get_garage_vocab',
               widget=SelectionWidget(label="Garage",
                                      label_msgid = "label_garage",
                                      description="Select whether this object has a garage",
                                      description_msgid = "desc_garage",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),
                
    TextField('kindOfGarage',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfGarage_vocab',
                widget=SelectionWidget(label="Kind of garage",
                                       label_msgid = "label_kindOfGarage",
                                       description="Select the garage type",
                                       description_msgid = "desc_kindOfGarage",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    LinesField('heating',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_heating_vocab',
                widget=MultiSelectionWidget(label="Heating",
                                            label_msgid = "label_heating",
                                            description="""Select the heating for this object. You can choose more than 1 option. 
                                                           Multiple options can be selected/deselected by pressing Ctrl while 
                                                           left clicking the options""",
                                            description_msgid = "desc_heating",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    LinesField('isolation',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_isolation_vocab',
                widget=MultiSelectionWidget(label="Isolation",
                                            label_msgid = "label_isolation",
                                            description="""Select the isolation for this object. You can choose more than 1 option. 
                                                           Multiple options can be selected/deselected by pressing Ctrl while 
                                                           left clicking the options""",
                                            description_msgid = "desc_isolation",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),
                
    TextField('airco',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_airco_vocab',
                widget=SelectionWidget(label="Airconditioning",
                                       label_msgid = "label_airco",
                                       description="Select whether this object has an airconditioning",
                                       description_msgid = "desc_airco",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
                                                       
    TextField('acceptance',
               required = 1,
               default_content_type = 'text/restructured',
               default_output_type = 'text/html',
               allowable_content_types = ('text/html',),
               widget = RichWidget(description = "Enter a brief description for the acceptance",
                                   description_msgid = "desc_acceptance",
                                   label = "Acceptance",
                                   label_msgid = "label_acceptance",
                                   i18n_domain = "broker",
                                   rows = 25),
               schemata='Acceptance' ), 
                            
    )) 


class REHome(BaseFolder):

    """A simple folderish archetype"""
    schema = schema
    content_icon = "h_icon.gif"
    meta_type = "REHome"
    archetype_name = "REHome"
    product_meta_type = "REHome" 
    allowed_content_types = (['Photo Album'])

    def _get_city_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('city')
    
    def _get_rooms_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('rooms')
    
    def _get_type_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('type')
    
    def _get_kindOfBuilding_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('kindOfBuilding')

    def _get_balcony_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('balcony')

    def _get_garden_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('garden')

    def _get_kindOfGarden_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('kindOfGarden')

    def _get_location_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('location')

    def _get_storage_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('storage')

    def _get_garage_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('garage')

    def _get_kindOfGarage_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('kindOfGarage')

    def _get_heating_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('heating')

    def _get_isolation_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('isolation')

    def _get_airco_vocab(self):
        props = self.portal_properties.realestate_properties
        return props.getProperty('airco')
    
    def CookedPrice(self):
        """Return formatted price"""
        pr = str(self.price)
        elements = []
        
        if len(pr) > 9:
            elements.append(pr[-12:-9])
        if len(pr) > 6:
            elements.append(pr[-9:-6])
        if len(pr) > 3:
            elements.append(pr[-6:-3])
        elements.append(pr[-3:])
        return '.'.join(elements)
   
    def CookedBody(self):
        """Dummy attribute to allow drop-in replacement of Document"""
        return self.getMainText()
 
    def CookedAcceptance(self):
        """Dummy attribute to allow drop-in replacement of Document"""
        return self.getAcceptance()

    actions = ({'id': 'view',
                'name': 'View',
                'action': 'REHome_view',
                'permissions': (CMFCorePermissions.View,)
                },)
        
registerType(REHome)
